                                                                          /*  GENSTBLS.SQL  */

--  Build and load the interim tables that are used in generating sample data.
--  These tables are not part of the database, they are just used for 
--  loading the sample data into the database.
-- 
--  Sample data for the entire database is generated in GENSDATA.SQL.  
-- 
--  Don't forget to say 'USE Credit' first.

USE Credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'Credit')
BEGIN
   RAISERROR ('Database "Credit" not found.',22,127) WITH LOG
END
GO


PRINT 'Begin GENSTBLS.SQL'
GO



--  If the work tables already exist (i.e. if this is a rebuild), drop them.

IF EXISTS ( SELECT name
            FROM sysobjects
            WHERE type = 'U'
            AND name IN ( 'integer_table',
                          'lastname_table',
                          'firstname_table',
                          'corpname_table',
                          'street_table',
                          'address_table',
                          'letter_table' ) )
BEGIN
    DROP TABLE integer_table
    DROP TABLE lastname_table
    DROP TABLE firstname_table
    DROP TABLE corpname_table
    DROP TABLE street_table
    DROP TABLE address_table
    DROP TABLE letter_table
END
GO


		 /*  Will have one row each for integers 1 thru 100.  */
		 /*  Used to generate up to 100 copies of each item.  */
CREATE TABLE integer_table
  (
  integer          int          NOT NULL
  )


CREATE TABLE lastname_table   -- Will have 26 last names, one each for A - Z.
  (
  int_key          int          NOT NULL IDENTITY,
  lastname         shortstring  NOT NULL 
  )


CREATE TABLE firstname_table  -- Will have 26 first names, one each for A - Z.
  (
  int_key          int          NOT NULL IDENTITY,
  firstname        shortstring  NOT NULL 
  )


CREATE TABLE corpname_table   -- Will have 100 corp names.
  (
  int_key          int          NOT NULL IDENTITY,
  corpname         normstring   NOT NULL 
  )


CREATE TABLE letter_table   --  Will have 26 initials, one each for A - Z.
  (
  integer          int          NOT NULL,
  letter           letter       NOT NULL
  )


CREATE TABLE street_table   --  Will have 23 streets.
  (
  integer          int          NOT NULL,
  street           shortstring  NOT NULL
  )


CREATE TABLE address_table  -- Will have 13 city / state / zips.
  (
  integer          int          NOT NULL,
  city             shortstring  NOT NULL,
  state            statecode    NOT NULL,
  zip              mailcode     NOT NULL
  )


/*
CREATE TABLE date_table     --  Will have 12 dates.
  (
  integer          int          NOT NULL,
  date             datetime     NOT NULL
  )
CREATE TABLE language_table  -- Will have 20 languages.
  (
  integer          int          NOT NULL,
  descr            shortstring  NOT NULL
  )
*/
GO



--  Load corpname table.

INSERT lastname_table     VALUES     ('Key Stones')
INSERT lastname_table     VALUES     ('Lighting')
INSERT lastname_table     VALUES     ('Machinery')
INSERT lastname_table     VALUES     ('Needlework')

INSERT firstname_table    VALUES     ('Apex')
INSERT firstname_table    VALUES     ('Boston')
INSERT firstname_table    VALUES     ('Computer')
INSERT firstname_table    VALUES     ('Driven')
INSERT firstname_table    VALUES     ('Expert')
INSERT firstname_table    VALUES     ('Famous')
INSERT firstname_table    VALUES     ('Giant')
INSERT firstname_table    VALUES     ('Humble')
INSERT firstname_table    VALUES     ('Imperial')
INSERT firstname_table    VALUES     ('Just')
INSERT lastname_table     VALUES     ('Opera')
INSERT lastname_table     VALUES     ('Petroleum')
INSERT lastname_table     VALUES     ('Quests')
INSERT lastname_table     VALUES     ('Restaurants')
INSERT lastname_table     VALUES     ('Sail Makers')
INSERT lastname_table     VALUES     ('Transit')

INSERT corpname_table
   SELECT firstname + ' ' + lastname + 'Inc.'
   FROM firstname_table, lastname_table
INSERT corpname_table
   SELECT firstname + ' ' + lastname + 'Co.'
   FROM firstname_table, lastname_table
INSERT corpname_table
   SELECT firstname + ' ' + lastname + 'Corp.'
   FROM firstname_table, lastname_table
INSERT corpname_table
   SELECT firstname + ' ' + lastname + 'Ltd.'
   FROM firstname_table, lastname_table
INSERT corpname_table
   SELECT firstname + ' ' + lastname + 'Ag.'
   FROM firstname_table, lastname_table
GO

DUMP TRANSACTION Credit WITH TRUNCATE_ONLY
GO



--  Load lastname_table.

TRUNCATE TABLE lastname_table
INSERT lastname_table     VALUES     ('ANDERSON')
INSERT lastname_table     VALUES     ('BARR')
INSERT lastname_table     VALUES     ('CHEN')
INSERT lastname_table     VALUES     ('DORR')
INSERT lastname_table     VALUES     ('EFLIN')
INSERT lastname_table     VALUES     ('FLORINI')
INSERT lastname_table     VALUES     ('GOHAN')
INSERT lastname_table     VALUES     ('HAHN')
INSERT lastname_table     VALUES     ('INFANTE')
INSERT lastname_table     VALUES     ('JONES')
INSERT lastname_table     VALUES     ('KAHRMANN')
INSERT lastname_table     VALUES     ('LING')
INSERT lastname_table     VALUES     ('MAKAI')
INSERT lastname_table     VALUES     ('NELSON')
INSERT lastname_table     VALUES     ('OLPHANT')
INSERT lastname_table     VALUES     ('PAYNTER')
INSERT lastname_table     VALUES     ('QUINT')
INSERT lastname_table     VALUES     ('RYAN')
INSERT lastname_table     VALUES     ('STEIN')
INSERT lastname_table     VALUES     ('TOLSKY')
INSERT lastname_table     VALUES     ('UNAKLET')
INSERT lastname_table     VALUES     ('VANN')
INSERT lastname_table     VALUES     ('WOLFMULE')
INSERT lastname_table     VALUES     ('XAVIER')
INSERT lastname_table     VALUES     ('YEONG')
INSERT lastname_table     VALUES     ('ZUCKER')
GO


--  Load firstname_table.

TRUNCATE TABLE firstname_table
INSERT firstname_table    VALUES     ('ANDREW')
INSERT firstname_table    VALUES     ('BILL')
INSERT firstname_table    VALUES     ('CASSANDRA')
INSERT firstname_table    VALUES     ('DENNIS')
INSERT firstname_table    VALUES     ('ELLEN')
INSERT firstname_table    VALUES     ('FRANCES')
INSERT firstname_table    VALUES     ('GILLBER')
INSERT firstname_table    VALUES     ('HELLEN')
INSERT firstname_table    VALUES     ('IMANNA')
INSERT firstname_table    VALUES     ('JAYNE')
INSERT firstname_table    VALUES     ('KARL')
INSERT firstname_table    VALUES     ('LUCY')
INSERT firstname_table    VALUES     ('MAX')
INSERT firstname_table    VALUES     ('NELLIE')
INSERT firstname_table    VALUES     ('ORPAH')
INSERT firstname_table    VALUES     ('PATRICIA')
INSERT firstname_table    VALUES     ('QUINTEN')
INSERT firstname_table    VALUES     ('REDD')
INSERT firstname_table    VALUES     ('SANDRA')
INSERT firstname_table    VALUES     ('TAMMY')
INSERT firstname_table    VALUES     ('UTA')
INSERT firstname_table    VALUES     ('VINCENT')
INSERT firstname_table    VALUES     ('WANDA')
INSERT firstname_table    VALUES     ('XAVIER')
INSERT firstname_table    VALUES     ('YOLANDA')
INSERT firstname_table    VALUES     ('ZYLPHA')
GO


-- Load letter_table.

INSERT letter_table  -- column Letter is char(1), so lastname is truncated.
    SELECT int_key, Substring(lastname,1,1) FROM lastname_table
GO


--  Load street_table.

INSERT street_table    VALUES     (   1,   'APPLE LN.')
INSERT street_table    VALUES     (   2,   'BOWERY ESTATES')
INSERT street_table    VALUES     (   3,   'CANNERY ROW')
INSERT street_table    VALUES     (   4,   'DOGWOOD DR.')
INSERT street_table    VALUES     (   5,   'ELM ST.')
INSERT street_table    VALUES     (   6,   'FILM STAR DR.')
INSERT street_table    VALUES     (   7,   'GOSHEN RD.')
INSERT street_table    VALUES     (   8,   'THE HIGHLANDS')
INSERT street_table    VALUES     (   9,   'IMAGE TYPE WAY')
INSERT street_table    VALUES     (  10,   'JAMES RD.')
INSERT street_table    VALUES     (  11,   'KING ST.')
INSERT street_table    VALUES     (  12,   'LINEAR CURVE')
INSERT street_table    VALUES     (  13,   'MAPLE ST.')
INSERT street_table    VALUES     (  14,   'NEW PIKE RD.')
INSERT street_table    VALUES     (  15,   'OREGON TR.')
INSERT street_table    VALUES     (  16,   'POTHOLE WAY')
INSERT street_table    VALUES     (  17,   'QUEEN ANNE DR.')
INSERT street_table    VALUES     (  18,   'RACE TRACK RD.')
INSERT street_table    VALUES     (  19,   'STONEY WAY')
INSERT street_table    VALUES     (  20,   'TIGHT ROPE RD.')
INSERT street_table    VALUES     (  21,   'UPPER LOWLANDS')
INSERT street_table    VALUES     (  22,   'VIKING VINE LN.')
INSERT street_table    VALUES     (  23,   'WILLOW RD.')
GO


--  Load address_table.

INSERT address_table    VALUES     (   1,   'SEATTLE', 'WA', '98124')
INSERT address_table    VALUES     (   2,   'SEATTLE', 'WA', '98022')
INSERT address_table    VALUES     (   3,   'SEATTLE', 'WA', '98102')
INSERT address_table    VALUES     (   4,   'KENT', 'WA', '98206')
INSERT address_table    VALUES     (   5,   'RENTON', 'WA', '98012')
INSERT address_table    VALUES     (   6,   'KIRKLAND', 'WA', '98033-1000')
INSERT address_table    VALUES     (   7,   'REDMOND', 'WA', '98052')
INSERT address_table    VALUES     (   8,   'AUBURN', 'WA', '98007')
INSERT address_table    VALUES     (   9,   'EDMONDS', 'WA', '98136-0333')
INSERT address_table    VALUES     (  10,   'WEST SEATTLE', 'WA', '98055')
INSERT address_table    VALUES     (  11,   'LYNNWOOD', 'WA', '98072')
INSERT address_table    VALUES     (  12,   'NOME', 'AK', '97890')
INSERT address_table    VALUES     (  13,   'GRESHAM', 'OR', '99432')
GO


--  Load integer_table.

--    There are two ways in which you can load a table with identity type values.
--    One traditional way is to use the code in this commented section that uses
--    a WHILE loop combined with SELECT MAX(col) and loop through incremmenting
--    and insert you values until your maximum value is reached.
--
--    ----------------------------------------------
--    INSERT integer_table VALUES (1)
--
--    WHILE (SELECT MAX(integer) FROM integer_table) < 100
--    BEGIN
--    INSERT integer_table
--        SELECT integer + (SELECT MAX(integer) FROM integer_table)
--        FROM integer_table
--    END
--    ----------------------------------------------
--
--    The other method also uses a WHILE loop but instead of coding the increment
--    routine you can use the IDENTITY property combined with the key words
--    "DEFAULT VALUES" used in the INSERT statement to do it for you. This does
--    require that your table.column be defined using the IDENTITY property.
--
--    The first method, shown above, is faster but more complex to write.  The
--    second method, used below, is simpler to write and read, but slower.
--    And without the BEGIN/COMMIT TRANSACTION it is an additional 33% slower.
--
--   ----------------------------------------------------------------------*
--    BEGIN TRANSACTION
--    WHILE @@identity < 100 OR (SELECT MAX(integer) FROM integer_table) IS NULL
--      BEGIN
--         INSERT integer_table DEFAULT VALUES
--      END
--    COMMIT TRANSACTION
--
--    DELETE FROM integer_table
--       WHERE integer > 100
--
--   ------------------------------------------------------------------------

INSERT integer_table VALUES (1)

    WHILE (SELECT MAX(integer) FROM integer_table) < 100
    BEGIN
    INSERT integer_table
        SELECT integer + (SELECT MAX(integer) FROM integer_table )
        FROM integer_table
    END

    DELETE FROM integer_table
       WHERE integer > 100
GO

DUMP TRANSACTION Credit WITH TRUNCATE_ONLY
GO



